GestureWidgetDelegateFromState class
- Inheritance
-
- Object
- SingleChildLayoutDelegate
- GestureWidgetDelegateFromState
Constructors
- GestureWidgetDelegateFromState(ExtendedImageGestureState state, {BoxFit? imageFit, double? imageHeight, double? imageWidth, Rect? rect, bool copy = false})
Properties
- copy → bool
-
final
- destinationRect ↔ Rect?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- imageFit → BoxFit?
-
final
- imageHeight → double?
-
final
- imageWidth → double?
-
final
- rect → Rect?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → ExtendedImageGestureState
-
final
Methods
-
getConstraintsForChild(
BoxConstraints constraints) → BoxConstraints -
The constraints for the child given the incoming constraints.
override
-
getPositionForChild(
Size size, Size childSize) → Offset -
The position where the child should be placed.
override
-
getSize(
BoxConstraints constraints) → Size -
The size of this object given the incoming constraints.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRelayout(
covariant GestureWidgetDelegateFromState oldDelegate) → bool -
Called whenever a new instance of the custom layout delegate class is
provided to the RenderCustomSingleChildLayoutBox object, or any time
that a new CustomSingleChildLayout object is created with a new instance
of the custom layout delegate class (which amounts to the same thing,
because the latter is implemented in terms of the former).
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
getRectFormState(
Rect rect, ExtendedImageGestureState state, {double? width, double? height, BoxFit? fit, bool copy = false}) → Rect