TextLarge class

Large font

Inheritance
Available extensions

Constructors

TextLarge(String? text, {Key? key, bool usePrimaryColor = false, bool useStyleFirst = false, TextStyle? style, GestureRecognizer? recognizer, String? semanticsLabel, MouseCursor? mouseCursor, PointerEnterEventListener? onEnter, PointerExitEventListener? onExit, bool? spellOut, Locale? locale, StrutStyle? strutStyle, TextAlign? textAlign, TextDirection? textDirection, bool? softWrap, TextOverflow? overflow, int? maxLines, TextWidthBasis? textWidthBasis, TextHeightBehavior? textHeightBehavior, Color? selectionColor, TextScaler? textScaler = TextScaler.noScaling, bool inherit = true, Color? color, Color? backgroundColor, String? fontFamily, List<String>? fontFamilyFallback, String? package, double? fontSize, FontWeight? fontWeight, FontStyle? fontStyle, double? letterSpacing, double? wordSpacing, TextBaseline? textBaseline, double? height, Paint? foreground, Paint? background, TextDecoration? decoration = TextDecoration.none, Color? decorationColor, TextDecorationStyle? decorationStyle, double? decorationThickness, String? debugLabel, List<Shadow>? shadows, List<FontFeature>? fontFeatures, TextLeadingDistribution? leadingDistribution, List<FontVariation>? fontVariations})
const

Properties

background Paint?
text的背景色
finalinherited
backgroundColor Color?
finalinherited
color Color?
字体颜色,注意: 如果有特殊的foreground,此值必须是null
finalinherited
data String?
data
finalinherited
debugLabel String?
只在调试的使用
finalinherited
decoration TextDecoration?
text的划线 TextDecoration.none 没有 默认 TextDecoration.underline 下划线 TextDecoration.overline 上划线 TextDecoration.lineThrough 中间的线(删除线)
finalinherited
decorationColor Color?
decoration划线的颜色
finalinherited
decorationStyle TextDecorationStyle?
decoration划线的样式 TextDecorationStyle.solid实线 TextDecorationStyle.double 画两条线 TextDecorationStyle.dotted 点线(一个点一个点的) TextDecorationStyle.dashed 虚线(一个长方形一个长方形的线) TextDecorationStyle.wavy 正玄曲线
finalinherited
decorationThickness double?
finalinherited
expand SizedBox

Available on Widget, provided by the ExtensionWidget extension

no setter
expanded Expanded

Available on Widget, provided by the ExtensionWidget extension

no setter
flexible Flexible

Available on Widget, provided by the ExtensionWidget extension

no setter
fontFamily String?
finalinherited
fontFamilyFallback List<String>?
finalinherited
fontFeatures List<FontFeature>?
finalinherited
fontSize double?
字体大小 默认的是 14
finalinherited
fontStyle FontStyle?
FontStyle.normal正常 FontStyle.italic斜体
finalinherited
fontVariations List<FontVariation>?
finalinherited
fontWeight FontWeight?
字体的粗细程度 FontWeight.w100 -- FontWeight.w900 . 默认是FontWeight.w400,
finalinherited
foreground Paint?
text的前景色,与 color 不能同时设置
finalinherited
hashCode int
The hash code for this object.
no setterinherited
height double?
文本的高度 主要用于TextSpan 来设置不同的高度
finalinherited
inherit bool
---------- TextStyle ---------- 默认样式会继承层级最为接近的 DefaultTextStyle,为true 表示继承,false 表示完全重写
finalinherited
inlineSpan InlineSpan?
The text to display as a InlineSpan.
finalinherited
inlineSpans List<InlineSpan>?
多个InlineSpan
finalinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
leadingDistribution TextLeadingDistribution?
finalinherited
letterSpacing double?
单个字母或者汉字的距离,默认是1.0,负数可以拉近距离
finalinherited
locale Locale?
Locale,当相同的Unicode字符可以根据不同的地区以不同的方式呈现时,用于选择字体
finalinherited
maxLines int?
int 设置文字的最大展示行数
finalinherited
mouseCursor MouseCursor?
mouseCursor
finalinherited
onEnter PointerEnterEventListener?
onEnter
finalinherited
onExit PointerExitEventListener?
onExit
finalinherited
overflow TextOverflow?
TextOverflow,内容溢出时的处理方式
finalinherited
package String?
finalinherited
recognizer GestureRecognizer?
---------- TextSpan ---------- text手势
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectionColor Color?
The color to use when painting the selection.
finalinherited
semanticsIdentifier String?
finalinherited
semanticsLabel String?
text语义 - 语义描述标签,相当于此text的别名
finalinherited
shadows List<Shadow>?
将在text下方绘制的阴影列表
finalinherited
shrink SizedBox

Available on Widget, provided by the ExtensionWidget extension

no setter
softWrap bool?
bool 文本是否应在软换行时断行
finalinherited
spellOut bool?
spellOut
finalinherited
strutStyle StrutStyle?
StrutStyle,影响Text在垂直方向上的布局
finalinherited
style TextStyle?
所有texts默认样式
finalinherited
textAlign TextAlign?
---------- Text ---------- How the text should be aligned horizontally.
finalinherited
textBaseline TextBaseline?
TextBaseline.ideographic用来对齐表意文字的水平线 TextBaseline.alphabetic 以标准的字母顺序为基线
finalinherited
textDirection TextDirection?
TextDirection,内容的走向方式
finalinherited
textFontSize TextFontSize?
字体大小
finalinherited
textHeightBehavior TextHeightBehavior?
Defines how to apply TextStyle.height over and under text.
finalinherited
textScaler TextScaler?
The font scaling strategy to use when laying out and rendering the text.
finalinherited
textWidthBasis TextWidthBasis?
TextWidthBasis 测量一行或多行文本宽度
finalinherited
toExpansionTilesRotationIconBuilder ExpansionTilesRotationIconBuilder

Available on Widget, provided by the ExtensionExpansionTiles extension

no setter
toLoadingBuilder LoadingBuilder

Available on Widget, provided by the ExtensionWidget extension

no setter
toRoutePageBuilder RoutePageBuilder

Available on Widget, provided by the ExtensionWidget extension

no setter
toRouteTransitionsBuilder RouteTransitionsBuilder

Available on Widget, provided by the ExtensionWidget extension

no setter
toSliverBox Widget

Available on Widget, provided by the ExtensionWidget extension

no setter
toToastBuilder ToastBuilder

Available on Widget, provided by the ExtensionWidget extension

no setter
toToggleRotateIconBuilder ToggleRotateIconBuilder

Available on Widget, provided by the ExtensionWidgetToggleRotate extension

no setter
toWidgetBuilder WidgetBuilder

Available on Widget, provided by the ExtensionWidget extension

no setter
usePrimaryColor bool
使用主色调设置字体颜色
finalinherited
useStyleFirst bool
colorstyle中都有值 useStyleFirst=true 优先使用style, useStyleFirst=false 优先使用外层,
finalinherited
wordSpacing double?
单词之间添加的空间间隔,负数可以拉近距离
finalinherited

Methods

align({Key? key, Alignment alignment = Alignment.center, double? widthFactor, double? heightFactor}) Align

Available on Widget, provided by the ExtensionWidget extension

aspectRatio(double aspectRatio, {Key? key}) AspectRatio

Available on Widget, provided by the ExtensionWidget extension

backdropFilter({Key? key, ImageFilter? filter, double fuzzyDegree = 4}) BackdropFilter

Available on Widget, provided by the ExtensionWidget extension

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
inherited
card({Color? color, Color? shadowColor, double? elevation, ShapeBorder? shape, bool? borderOnForeground, EdgeInsetsGeometry? margin, Clip? clipBehavior, bool? semanticContainer}) Card

Available on Widget, provided by the ExtensionWidget extension

center({Key? key, double? widthFactor, double? heightFactor}) Center

Available on Widget, provided by the ExtensionWidget extension

clipOval({Key? key, BorderRadius borderRadius = BorderRadius.zero, CustomClipper<Rect>? clipper, Clip clipBehavior = Clip.antiAlias}) ClipOval

Available on Widget, provided by the ExtensionWidget extension

clipPath({Key? key, BorderRadius borderRadius = BorderRadius.zero, CustomClipper<Path>? clipper, Clip clipBehavior = Clip.antiAlias}) ClipPath

Available on Widget, provided by the ExtensionWidget extension

clipRRect({Key? key, BorderRadius borderRadius = BorderRadius.zero, CustomClipper<RRect>? clipper, Clip clipBehavior = Clip.antiAlias}) ClipRRect

Available on Widget, provided by the ExtensionWidget extension

color(Color color, {Key? key}) ColoredBox

Available on Widget, provided by the ExtensionWidget extension

constrainedBox(BoxConstraints constraints, {Key? key}) ConstrainedBox

Available on Widget, provided by the ExtensionWidget extension

container({Key? key, EdgeInsetsGeometry? padding, Decoration? foregroundDecoration, Matrix4? transform, BoxConstraints? constraints, Color? color, double? width, double? height, EdgeInsetsGeometry? margin, Decoration? decoration, Clip? clipBehavior, AlignmentGeometry? alignment}) Container

Available on Widget, provided by the ExtensionWidget extension

createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
decoratedBox(Decoration decoration, {Key? key, DecorationPosition position = DecorationPosition.background}) DecoratedBox

Available on Widget, provided by the ExtensionWidget extension

fittedBox({Key? key, BoxFit fit = BoxFit.contain, AlignmentGeometry alignment = Alignment.center, Clip clipBehavior = Clip.none}) FittedBox

Available on Widget, provided by the ExtensionWidget extension

fromSize(Size size, {Key? key}) SizedBox

Available on Widget, provided by the ExtensionWidget extension

gestureDetector({Key? key, GestureTapDownCallback? onTapDown, GestureTapUpCallback? onTapUp, GestureTapCallback? onTap, GestureTapCancelCallback? onTapCancel, GestureTapDownCallback? onSecondaryTapDown, GestureTapUpCallback? onSecondaryTapUp, GestureTapCancelCallback? onSecondaryTapCancel, GestureTapCallback? onDoubleTap, GestureLongPressCallback? onLongPress, GestureLongPressStartCallback? onLongPressStart, GestureLongPressMoveUpdateCallback? onLongPressMoveUpdate, GestureLongPressUpCallback? onLongPressUp, GestureLongPressEndCallback? onLongPressEnd, GestureDragDownCallback? onVerticalDragDown, GestureDragStartCallback? onVerticalDragStart, GestureDragUpdateCallback? onVerticalDragUpdate, GestureDragEndCallback? onVerticalDragEnd, GestureDragCancelCallback? onVerticalDragCancel, GestureDragDownCallback? onHorizontalDragDown, GestureDragStartCallback? onHorizontalDragStart, GestureDragUpdateCallback? onHorizontalDragUpdate, GestureDragEndCallback? onHorizontalDragEnd, GestureDragCancelCallback? onHorizontalDragCancel, GestureForcePressStartCallback? onForcePressStart, GestureForcePressPeakCallback? onForcePressPeak, GestureForcePressUpdateCallback? onForcePressUpdate, GestureForcePressEndCallback? onForcePressEnd, GestureDragDownCallback? onPanDown, GestureDragStartCallback? onPanStart, GestureDragUpdateCallback? onPanUpdate, GestureDragEndCallback? onPanEnd, GestureDragCancelCallback? onPanCancel, GestureScaleStartCallback? onScaleStart, GestureScaleUpdateCallback? onScaleUpdate, GestureScaleEndCallback? onScaleEnd, HitTestBehavior? behavior, bool excludeFromSemantics = false, DragStartBehavior dragStartBehavior = DragStartBehavior.start, Set<PointerDeviceKind>? supportedDevices, bool trackpadScrollCausesScale = false, Offset trackpadScrollToScaleFactor = kDefaultTrackpadScrollToScaleFactor}) GestureDetector

Available on Widget, provided by the ExtensionWidget extension

hero(Object tag, {Key? key, CreateRectTween? createRectTween, HeroFlightShuttleBuilder? flightShuttleBuilder, HeroPlaceholderBuilder? placeholderBuilder, bool transitionOnUserGestures = false}) Hero

Available on Widget, provided by the ExtensionWidget extension

interceptNotificationListener<T extends Notification>({NotificationListenerCallback<T>? onNotification}) Widget

Available on Widget, provided by the ExtensionNotificationListener extension

limitedBox({Key? key, double maxWidth = double.infinity, double maxHeight = double.infinity}) LimitedBox

Available on Widget, provided by the ExtensionWidget extension

margin(EdgeInsetsGeometry margin, {Key? key}) Padding

Available on Widget, provided by the ExtensionWidget extension

marginAll(double margin) Widget

Available on Widget, provided by the ExtensionWidget extension

marginOnly({double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0}) Widget

Available on Widget, provided by the ExtensionWidget extension

marginSymmetric({double horizontal = 0.0, double vertical = 0.0}) Widget

Available on Widget, provided by the ExtensionWidget extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
offstage(bool offstage, {Key? key}) Offstage

Available on Widget, provided by the ExtensionWidget extension

onDoubleTap(GestureTapCallback onDoubleTap, {Key? key}) GestureDetector

Available on Widget, provided by the ExtensionWidget extension

onLongPress(GestureLongPressCallback onLongPress, {Key? key}) GestureDetector

Available on Widget, provided by the ExtensionWidget extension

onTap(GestureTapCallback? onTap, {Key? key}) GestureDetector

Available on Widget, provided by the ExtensionWidget extension

overflowBox({Key? key, Alignment alignment = Alignment.center, double? minWidth, double? maxWidth, double? minHeight, double? maxHeight}) OverflowBox

Available on Widget, provided by the ExtensionWidget extension

padding(EdgeInsetsGeometry padding) Padding

Available on Widget, provided by the ExtensionWidget extension

paddingAll(double padding) Widget

Available on Widget, provided by the ExtensionWidget extension

paddingOnly({double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0}) Widget

Available on Widget, provided by the ExtensionWidget extension

paddingSymmetric({double horizontal = 0.0, double vertical = 0.0}) Widget

Available on Widget, provided by the ExtensionWidget extension

popupCupertinoModal<T>({WidgetBuilder? builder, CupertinoModalPopupOptions? options}) Future<T?>

Available on Widget, provided by the ExtensionWidgetMethod extension

全屏显示 showCupertinoModalPopup
popupGeneralDialog<T>({RoutePageBuilder? builder, GeneralDialogOptions? options}) Future<T?>

Available on Widget, provided by the ExtensionWidgetMethod extension

showGeneralDialog
popupModalBottomSheet<T>({WidgetBuilder? builder, ModalBottomSheetOptions? options}) Future<T?>

Available on Widget, provided by the ExtensionWidgetMethod extension

showModalBottomSheet 关闭 closePopup()
positioned({Key? key, double? left, double? top, double? right, double? bottom, double? width, double? height}) Positioned

Available on Widget, provided by the ExtensionWidget extension

push<T extends Object?>(Widget widget, {PageRouteOptions options = const PageRouteOptions.material()}) Future<T?>

Available on Widget, provided by the ExtensionWidgetMethod extension

push
pushAndRemoveUntil<T extends Object?>(Widget widget, {PageRouteOptions options = const PageRouteOptions.material(), required RoutePredicate predicate}) Future<T?>

Available on Widget, provided by the ExtensionWidgetMethod extension

pushAndRemoveUntil
pushReplacement<T extends Object?, TO extends Object?>(Widget widget, {PageRouteOptions options = const PageRouteOptions.material(), TO? result}) Future<T?>

Available on Widget, provided by the ExtensionWidgetMethod extension

pushReplacement
rotatedBox(int quarterTurns, {Key? key}) RotatedBox

Available on Widget, provided by the ExtensionWidget extension

setHeight(double height, {Key? key}) SizedBox

Available on Widget, provided by the ExtensionWidget extension

setPreferredHeight(double height, {Key? key}) PreferredSize

Available on Widget, provided by the ExtensionWidget extension

setPreferredSize(Size size, {Key? key}) PreferredSize

Available on Widget, provided by the ExtensionWidget extension

setPreferredWidth(double width, {Key? key}) PreferredSize

Available on Widget, provided by the ExtensionWidget extension

setSize(Size size, {Key? key}) SizedBox

Available on Widget, provided by the ExtensionWidget extension

setWidth(double width, {Key? key}) SizedBox

Available on Widget, provided by the ExtensionWidget extension

showOverlay({bool isCached = true}) FlOverlayEntry?

Available on Widget, provided by the ExtensionWidgetMethod extension

FlOverlay().show()
sizedBox({Key? key, double? width, double? height}) SizedBox

Available on Widget, provided by the ExtensionWidget extension

sizedOverflowBox(Size size, {Key? key, Alignment alignment = Alignment.center}) SizedOverflowBox

Available on Widget, provided by the ExtensionWidget extension

statusBarStyle(SystemUiOverlayStyle style) AnnotatedRegion<SystemUiOverlayStyle>

Available on Widget, provided by the ExtensionWidget extension

toDecoratorPendant<T>({DecoratorPendantPosition positioned = DecoratorPendantPosition.outer, bool maintainSize = false, bool? needFocus, bool? needEditing, DecoratorPendantValueCallback<T?>? needValue}) DecoratorPendant<T>

Available on Widget, provided by the ExtensionWidgetDecoratorBox extension

toDecoratorPendantBuilder<T>({DecoratorPendantPosition positioned = DecoratorPendantPosition.outer, bool maintainSize = false, bool? needFocus, bool? needEditing, DecoratorPendantValueCallback<T?>? needValue}) DecoratorPendant<T>

Available on Widget, provided by the ExtensionWidgetDecoratorBox extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited
toTextFieldPendant({DecoratorPendantPosition positioned = DecoratorPendantPosition.outer, bool maintainSize = false, bool? needFocus, bool? needEditing, DecoratorPendantValueCallback<TextEditingController?>? needValue}) TextFieldPendant

Available on Widget, provided by the ExtensionWidgetTextFieldPendant extension

toTextFieldPendantBuilder({DecoratorPendantPosition positioned = DecoratorPendantPosition.outer, bool maintainSize = false, bool? needFocus, bool? needEditing, DecoratorPendantValueCallback<TextEditingController?>? needValue}) TextFieldPendant

Available on Widget, provided by the ExtensionWidgetTextFieldPendant extension

unconstrainedBox({Key? key, TextDirection? textDirection, Alignment alignment = Alignment.center, Axis? constrainedAxis}) UnconstrainedBox

Available on Widget, provided by the ExtensionWidget extension

visibility(bool visible, {Key? key}) Visibility

Available on Widget, provided by the ExtensionWidget extension

Operators

operator ==(Object other) bool
The equality operator.
inherited